@@ -7,19 +7,20 @@
 #' @return A list providing the observed test statistic (\code{kdplus}) and the estimate p-value {\code{pvalue}}.
 #' @author Joshua French
 #' @import spatstat
+#' @importFrom stats sd
 #' @export
 #' @references Waller, L.A. and Gotway, C.A. (2005).  Applied Spatial Statistics for Public Health Data.  Hoboken, NJ: Wiley.  Diggle, Peter J., and Amanda G. Chetwynd. "Second-order analysis of spatial clustering for inhomogeneous populations." Biometrics (1991): 1155-1163.
 #' @examples 
 #' data(grave)
-#' kdsim = kdest(grave, nsim = 19)
+#' kdsim = kdest(grave, nsim = 9)
 #' kdplus.test(kdsim)
 
 kdplus.test = function(x)
 {
-  if(max(class(x) == "kdenv") < 1) stop("x must be an object from the kd.env function.")
-  simfuns <- as.data.frame(attr(x, "simfuns"))
+  if(max(class(x) == "kdenv") < 1) stop("x must be an object from the kdenv function.")
+  simfuns <- as.data.frame(attr(x[[1]], "simfuns"))
   simfuns[,1] <- x$obs # replace r with obs kd
-  sdkdhat = apply(simfuns, 1, sd) # estimated variance of kdest simulations
+  sdkdhat = apply(simfuns, 1, stats::sd) # estimated variance of kdest simulations
   # turn into matrix
   sdmat = matrix(sdkdhat, nrow = nrow(simfuns), ncol = ncol(simfuns))
   # estimate KD + for simulated data
